@@ -76,6 +76,51 @@ expect_similar <- function(var, data2, var2, flt = TRUE, flt2 = flt,
 }
 
 
+#' @export
+#' @rdname expect-deprec
+#' @inheritParams generic-expectations
+#' @param allany The function to combine the `func` results for each row.
+expect_allany <- function(vars,
+                          func,
+                          flt = TRUE,
+                          data = get_testdata(),
+                          args = list(),
+                          allany = c(chk_filter_all, chk_filter_any),
+                          func_desc = NULL) {
+  lifecycle::deprecate_soft(
+    "0.4.1",
+    "expect_allany()",
+    details = "Please use `expect_all() or `expect_any()` instead"
+  )
+
+  check_expect_data_pipe(enquo(vars))
+  act <- quasi_label(enquo(data))
+  act$func_desc <- if (is.null(func_desc)) paste0("`", as_label(enquo(func)), "`") else func_desc
+  act$var_desc  <- as_label_vars(enquo(vars))
+  act$flt_desc  <- as_label_flt(enquo(flt))
+  act$args_desc <- expr_deparse_repl(args, "(^<list: |>$)", "")
+
+  act$result <- allany(eval_tidy(enquo(data)),
+                       {{ vars }},
+                       eval_tidy(enquo(func)),
+                       {{ flt }},
+                       args)
+
+  expect_custom(
+    all(act$result, na.rm = TRUE),
+    glue("{act$lab} has {sum(!act$result, na.rm = TRUE)} records failing \\
+          {act$func_desc} on variable `{act$var_desc}`.
+          Filter: {act$flt_desc}
+          Arguments: `{act$args_desc}`"),
+    failed_count = sum(!act$result, na.rm = TRUE),
+    total_count = sum(!is.na(act$result)),
+    var_desc = act$var_desc,
+    result = act$result
+  )
+
+  invisible(act$result)
+}
+
 #' Defunct expectation functions
 #'
 #' @description
